<script>
import {MasterMethods} from "@/Store/Functions.js";
import AppLayout from "@/Layouts/AppLayout.vue";
import {useForm} from "@inertiajs/vue3";
import Toast from "@/Componentes/Toastify/Toast.vue";

export default {
    name: "Categories",
    components: {Toast, AppLayout},
    created() {
        this.$page.props.breadcrumbs.push("Configuración");
        this.$page.props.breadcrumbs.push("Categorías");
    },
    data() {
        return{
            categories: [],
            category: useForm({id: null, name: null}),
            editing: false
        }
    },
    methods: {
        ...MasterMethods,
        submit() {
            this.resetForm(this.category);
            this.category.post(route('categories.store'),{
                preserveScroll: true,
                onSuccess: () => {
                    this.category.reset();
                }
            });
        },
        setCategory(item) {
            this.category.id = item.id;
            this.category.name = item.name;
        }
    },
}
</script>

<template>
    <AppLayout title="Categorias del Sitio">
        <Toast :response="category" />
        <div class="container">
            <div class="row justify-content-md-between">
                <div class="col-sm-12 col-md-4">
                    <div class="card card-primary card-outline">
                        <div class="card-body">
                            <table class="table table-sm">
                                <thead>
                                <tr>
                                    <th>Id</th>
                                    <th>Categoria</th>
                                    <th></th>
                                </tr>
                                </thead>
                                <tbody>
                                <tr v-if="$page.props?.categories.length > 0" v-for="item in $page.props.categories">
                                    <th>{{ item.id }}</th>
                                    <td>{{ item.name }}</td>
                                    <td class="text-end">
                                        <span class="fa fa-trash text-red-700 cursor-pointer me-2"></span>
                                        <span @click="setCategory(item)" class="fa fa-edit text-cyan-700 cursor-pointer"></span>
                                    </td>
                                </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
                <div class="col-sm-12 col-md-4">
                    <div class="card card-dark card-outline rounded-0">
                        <div class="card-header py-1">
                            <h3 class="card-title font-bold text-sm">Agregar Categoria</h3>
                        </div>
                        <div class="card-body">
                            <form v-on:submit.prevent="submit">
                                <div class="form-group">
                                    <label for="exampleInputBorder">Nombre:</label>
                                    <input type="text" required class="form-control form-control-border" v-model="category.name" placeholder="Nombre para la categoria">
                                </div>
                                <div class="text-end">
                                    <button type="reset" @click="category.reset()" class="btn bg-red-500 hover:bg-red-400 text-white btn-sm me-2">Cancelar</button>
                                    <button v-if="category.id" class="btn bg-cyan-500 hover:bg-cyan-400 text-white btn-sm">Actualizar</button>
                                    <button v-else class="btn bg-cyan-500 hover:bg-cyan-400 text-white btn-sm">Aceptar</button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </AppLayout>
</template>

<style scoped>

</style>
